First, usher has not been updated to exec 'mtn' by default rather than
'monotone'; this is not a big deal to work around (usher -m mtn), but
the default should probably be changed.  A trivial patch is attached.

Second, with both the usher from 0.26-pre3 and the usher from 0.26 as
released, I am having trouble serving some databases which worked in
0.26-pre2.  I am serving three databases from three 'local' stanzas
(net.elitists.elb.configs.*, edu.purdue.cs.gsb.guide.*, and
net.elitists.ical.*), and when I try to connect to
net.elitists.elb.configs.fvwm, usher spawns a server for
net.elitists.ical.* and connects my pull to that server -- needless to
say, this doesn't work.  A copy of my usher server file is likewise
attached.  (Additionally, usher dumps core on ^c, which isn't a huge
deal in and of itself, but makes me nervous -- it appears to be
double-destroying one of its data structures, but I haven't had time
to dig too deep.)

Ethan

-- 
The laws that forbid the carrying of arms are laws [that have no remedy
for evils].  They disarm only those who are neither inclined nor
determined to commit crimes.
                -- Cesare Beccaria, "On Crimes and Punishments", 1764
userpass usher-admin fakepass

server guide
host nestor.cs.purdue.edu
host localhost
pattern edu.purdue.cs.gsb.guide.*
local -k [EMAIL PROTECTED] -d /homes/eblanton/stuff/monotone/server/guide.mtn 
edu.purdue.cs.guide*

server configs
host nestor.cs.purdue.edu
host localhost
pattern net.elitists.elb.configs.*
local -k [EMAIL PROTECTED] -d /homes/eblanton/stuff/monotone/server/configs.mtn 
net.elitists.elb.configs.*

server ical
host nestor.cs.purdue.edu
host localhost
pattern net.elitists.ical*
local -k [EMAIL PROTECTED] -d /homes/eblanton/stuff/monotone/server/ical.mtn 
net.elitists.ical*
# 
# old_revision [512820e126f1c9d6e60612aff1e95f7fe3af983a]
# 
# patch "contrib/usher.cc"
#  from [599b754c575694458973cf7ecd5be5fd5a03c06d]
#    to [fe0d5a16bd4b84cf969228c6e05f1cff85614379]
# 
============================================================
--- contrib/usher.cc    599b754c575694458973cf7ecd5be5fd5a03c06d
+++ contrib/usher.cc    fe0d5a16bd4b84cf969228c6e05f1cff85614379
@@ -16,7 +16,7 @@
 // Usage: usher [-l address[:port]] [-a address:port] [-p pidfile] 
<server-file>
 //
 // options:
 // -m   the monotone command, defaults to "monotone"
 // -l   address and port to listen on, defaults to 0.0.0.0:4691
 // -a   address and port to listen for admin commands
 // -p   a file (deleted on program exit) to record the pid of the usher in
@@ -51,8 +51,8 @@
 // A request to server "hostname" will be directed to the
 // server at <ip-address>:<port-number>, if that stem is marked as remote,
 // and to a local server managed by the usher, started with the given
-// arguments ("monotone serve --bind=something <server arguments>"),
-// if it is marked as local.
+// arguments ("mtn serve --bind=something <server arguments>"), if it is
+// marked as local.
 // Note that "hostname" has to be an initial substring of who the client asked
 // to connect to, but does not have to match exactly. This means that you don't
 // have to know in advance whether clients will be asking for
@@ -161,7 +161,7 @@
 // defaults, overridden by command line
 int listenport = 4691;
 string listenaddr = "0.0.0.0";
-string monotone = "monotone";
+string monotone = "mtn";
 
 // keep local servers around for this many seconds after the last
 // client disconnects from them (only accurate to ~10 seconds)
@@ -16,7 +16,7 @@
 //
 // options:
-// -m   the monotone command, defaults to "monotone"
+// -m   the monotone command, defaults to "mtn"
 // -l   address and port to listen on, defaults to 0.0.0.0:4691
 // -a   address and port to listen for admin commands

Attachment: signature.asc
Description: Digital signature

_______________________________________________
Monotone-devel mailing list
Monotone-devel@nongnu.org
http://lists.nongnu.org/mailman/listinfo/monotone-devel

Reply via email to